@@ -40,7 +40,7 @@ private:
     QString fileName();
 
 private:
-    QTemporaryDir *mTempDir;
+    QTemporaryDir *mTempDir = nullptr;
     KMime::Message::Ptr mMail1;
 };
 
